/* Jaguar C library */
/* Copyright (C) 2006 Seb/The Removers */
/* http://removers.atari.org/ */

/* This library is free software; you can redistribute it and/or */
/* modify it under the terms of the GNU Lesser General Public */
/* License as published by the Free Software Foundation; either */
/* version 2.1 of the License, or (at your option) any later version. */

/* This library is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU */
/* Lesser General Public License for more details. */

/* You should have received a copy of the GNU Lesser General Public */
/* License along with this library; if not, write to the Free Software */
/* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA */

/** \file ctype.h
 * \brief Character filters.
 */
#ifndef __CTYPE_H
#define __CTYPE_H

/** Is a letter or a digit? 

    @param c = a character

    @return TRUE if c is a letter or a digit, FALSE otherwise 

    \hideinitializer */
int isalnum(int c);

/** Is a letter? 

    @param c = a character

    @return TRUE if c is a letter, FALSE otherwise 

    \hideinitializer */
int isalpha(int c);

/** Is a control character? 

   @param c = a character

    @return TRUE if c is a control character, FALSE otherwise 

    \hideinitializer */
int iscntrl(int c);

/** Is a digit? 

    @param c = a character

    @return TRUE if c is a digit, FALSE otherwise 

    \hideinitializer */
int isdigit(int c);

/** Is a printable character different from a whitespace? 

    @param c = a character

    @return TRUE if c is printable character different from a whitespace, FALSE otherwise 

    \hideinitializer */
int isgraph(int c);

/** Is lowercase letter? 

    @param c = a character

    @return TRUE if c is a lowercase letter, FALSE otherwise

    \hideinitializer */
int islower(int c);

/** Is a printable character? 

    @param c = a character

    @return TRUE if c is printable character, FALSE otherwise 

    \hideinitializer */
int isprint(int c);

/** Is a printable character different from a whitespace and being
    neither a letter nor a digit

    @param c = a character

    @return TRUE or FALSE

    \hideinitializer */
int ispunct(int c);

/** Is whitespace? 

    @param c = a character

    @return TRUE if c is whitespace, FALSE otherwise

    \hideinitializer */
int isspace(int c);

/** Is uppercase letter? 

    @param c = a character

    @return TRUE if c is an uppercase letter, FALSE otherwise

    \hideinitializer */
int isupper(int c);

/** Is hexa digit?

    @param c = a character

    @return TRUE if c is a hex digit, FALSE otherwise

    \hideinitializer */
int isxdigit(int c);

/** Conversion to uppercase 

    @param c = a character

    @return corresponding uppercase letter

    \hideinitializer */
int toupper(int c);

/** Conversion to lowercase 

    @param c = a character

    @return corresponding lowercase letter

    \hideinitializer */
int tolower(int c);

#endif
