/* Jaguar C library */
/* Copyright (C) 2006 Seb/The Removers */
/* http://removers.atari.org/ */

/* This library is free software; you can redistribute it and/or */
/* modify it under the terms of the GNU Lesser General Public */
/* License as published by the Free Software Foundation; either */
/* version 2.1 of the License, or (at your option) any later version. */

/* This library is distributed in the hope that it will be useful, */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU */
/* Lesser General Public License for more details. */

/* You should have received a copy of the GNU Lesser General Public */
/* License along with this library; if not, write to the Free Software */
/* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA */

#include <ctype.h>

/** Is a letter or a digit? 

    @param c = a character

    @return TRUE if c is a letter or a digit, FALSE otherwise 

    \hideinitializer */
int isalnum(int c)
{ int _c = c;
  return isalpha(_c) || isdigit(_c);
}

/** Is a letter? 

    @param c = a character

    @return TRUE if c is a letter, FALSE otherwise 

    \hideinitializer */
int isalpha(int c)
{ int _c = c;
  return ((islower(_c)) || (isupper(_c)));
}

/** Is a control character? 

   @param c = a character

    @return TRUE if c is a control character, FALSE otherwise 

    \hideinitializer */
int iscntrl(int c)
{ int _c = c;
  return (((_c >= 0) && (_c < 32)) || (_c == 127));
}

/** Is a digit? 

    @param c = a character

    @return TRUE if c is a digit, FALSE otherwise 

    \hideinitializer */
int isdigit(int c)
{ int _c = c;
  return ((_c >= '0') && (_c <= '9'));
}

/** Is a printable character different from a whitespace? 

    @param c = a character

    @return TRUE if c is printable character different from a whitespace, FALSE otherwise 

    \hideinitializer */
int isgraph(int c)
{ int _c = c;
  return ((isprint(_c)) && (!isspace(_c)));
}

/** Is lowercase letter? 

    @param c = a character

    @return TRUE if c is a lowercase letter, FALSE otherwise

    \hideinitializer */
int islower(int c)
{ int _c = c;
  return ((_c >= 'a') && (_c <= 'z'));
}

/** Is a printable character? 

    @param c = a character

    @return TRUE if c is printable character, FALSE otherwise 

    \hideinitializer */
int isprint(int c)
{ int _c = c;
  return ((_c >= 32) && (_c < 256));
}

/** Is a printable character different from a whitespace and being
    neither a letter nor a digit

    @param c = a character

    @return TRUE or FALSE

    \hideinitializer */
int ispunct(int c)
{ int _c = c;
  return ((isgraph(_c)) && (!isalnum(_c)));
}

/** Is whitespace? 

    @param c = a character

    @return TRUE if c is whitespace, FALSE otherwise

    \hideinitializer */
int isspace(int c)
{ int _c = c;
  return ((_c == '\f') || (_c == '\n') || (_c == '\r') || (_c == '\t') || (_c == '\v') || (_c == ' '));
}

/** Is uppercase letter? 

    @param c = a character

    @return TRUE if c is an uppercase letter, FALSE otherwise

    \hideinitializer */
int isupper(int c)
{ int _c = c;
  return ((_c >= 'A') && (_c <= 'Z'));
}

/** Is hexa digit?

    @param c = a character

    @return TRUE if c is a hex digit, FALSE otherwise

    \hideinitializer */
int isxdigit(int c)
{ int _c = c;
  return (isdigit(_c) || ((_c >= 'a') && (_c <= 'f')) || ((_c >= 'A') && (_c <= 'F')));
}

/** Conversion to uppercase 

    @param c = a character

    @return corresponding uppercase letter

    \hideinitializer */
int toupper(int c)
{ int _c = c;
  return (islower(_c))?(_c + 'A' - 'a'):_c;
}

/** Conversion to lowercase 

    @param c = a character

    @return corresponding lowercase letter

    \hideinitializer */
int tolower(int c)
{ int _c = c;
  return ((isupper(_c))?(_c + 'a' - 'A'):_c);
}
